@@ -9,6 +9,7 @@ from .authhandler import AuthHandler
 from cloudspot.endpoints.auth import AuthMethods
 from cloudspot.endpoints.artikels import ArtikelMethods
 from cloudspot.endpoints.klanten import KlantenMethods
+from cloudspot.endpoints.categorieen import CategorieenMethods
 from cloudspot.constants.errors import BadCredentials, NoValidToken
 
 class CloudspotERP_API:
@@ -78,6 +79,7 @@ class CloudspotERP_CompanyAPI(CloudspotERP_API):
         self.token = token
         
         self.artikels = ArtikelMethods(self)
+        self.categorieen = CategorieenMethods(self)
         self.klanten = KlantenMethods(self)
     
     def check_header_tokens(self):
