@@ -63,16 +63,14 @@ class ArtikelCategorie(BaseModel):
     def __init__(self,
         id=None,
         naam=None,
-        hoofdcategorie=None,
-        hoofdcategorie_id=None
+        children=None
     ):
         
         super().__init__()
         
         self.id = id
         self.naam = naam
-        self.hoofdcategorie = hoofdcategorie
-        self.hoofdcategorie_id = hoofdcategorie_id
+        self.children = children if children else ArtikelCategorieen()
 
 class ArtikelCategorieen(ObjectListModel):
     def __init__(self):
@@ -84,10 +82,12 @@ class Artikel(BaseModel):
         id=None,
         naam=None,
         beschrijving=None,
+        interne_notitie=None,
         merk=None,
         merk_id=None,
         categorie=None,
         categorie_id=None,
+        categorieen=None,
         SKU=None,
         voorraad_bijhouden=None,
         op_voorraad=None,
@@ -113,10 +113,12 @@ class Artikel(BaseModel):
         self.id = id
         self.naam = naam
         self.beschrijving = beschrijving
+        self.interne_notitie = interne_notitie
         self.merk = merk
         self.merk_id = merk_id
         self.categorie = categorie
         self.categorie_id = categorie_id
+        self.categorieen = categorieen if categorieen else ArtikelCategorieen()
         self.SKU = SKU
         self.voorraad_bijhouden = voorraad_bijhouden
         self.op_voorraad = op_voorraad
